@@ -296,8 +296,7 @@ update_apm_status(t_battmon *battmon)
         }
 
         if (acline && new_state != BM_MISSING) {
-            gchar *tmp = g_strdup(icon_name);
-            g_free(icon_name);
+            gchar *tmp = icon_name;
             new_state++;
             icon_name = g_strconcat(tmp, "-charging", NULL);
             g_free(tmp);
@@ -1118,12 +1117,12 @@ battmon_create_options(XfcePanelPlugin *plugin, t_battmon *battmon)
 
     xfce_panel_plugin_block_menu(plugin);
 
-    dlg = xfce_titled_dialog_new_with_buttons(_("Battery Monitor"),
-                                              GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))),
-                                              GTK_DIALOG_DESTROY_WITH_PARENT,
-                                              "gtk-help", GTK_RESPONSE_HELP,
-                                              "gtk-close", GTK_RESPONSE_OK,
-                                              NULL);
+    dlg = xfce_titled_dialog_new_with_mixed_buttons(_("Battery Monitor"),
+        GTK_WINDOW(gtk_widget_get_toplevel(GTK_WIDGET(plugin))),
+        GTK_DIALOG_DESTROY_WITH_PARENT,
+        "help-browser", _("_Help"), GTK_RESPONSE_HELP,
+        "window-close", _("_Close"), GTK_RESPONSE_OK,
+        NULL);
 
     xfce_titled_dialog_set_subtitle(XFCE_TITLED_DIALOG(dlg), _("Properties"));
     gtk_window_set_position(GTK_WINDOW(dlg), GTK_WIN_POS_CENTER);
@@ -1398,7 +1397,7 @@ battmon_show_about(XfcePanelPlugin *plugin, t_battmon *battmon)
         "version", PACKAGE_VERSION,
         "program-name", PACKAGE_NAME,
         "comments", _("Show and monitor the battery status"),
-        "website", "http://goodies.xfce.org/projects/panel-plugins/xfce4-battery-plugin",
+        "website", "https://goodies.xfce.org/projects/panel-plugins/xfce4-battery-plugin",
         "copyright", _("Copyright (c) 2003-2019\n"),
         "authors", auth, NULL);
 
